@@ -43,6 +43,15 @@ setMethod("show", "effectlite", function(object) {
     if(is(v, "formula")){v <- all.vars(v[[3]])}  
     cat("Covariates for propensity score V: ", paste0(v), "\n")
   }
+  
+  cat("\nLevels of Treatment Variable X \n")
+  tmp <- data.frame(vlevels$x,
+                    vlevels$levels.x.original,
+                    paste0("I_X=",vlevels$x))
+  names(tmp) <- c("X", 
+                  paste0(vnames$x, " (original)"), 
+                  "Indicator")
+  print(tmp, row.names=F, print.gap=3)
 
   
   if(nk>1){
@@ -52,10 +61,21 @@ setMethod("show", "effectlite", function(object) {
     tmp <- expand.grid(tmp)
     tmp$K <- vlevels$kstar
     tmp <- tmp[,ncol(tmp):1]
+    tmp$Indicator <- paste0("I_K=", vlevels$kstar)
     print(tmp, row.names=F, print.gap=3)
   }
   
   
+  if(nk>1){
+    cat("\nCells \n")
+    tmp <- expand.grid(K=vlevels$kstar, X=vlevels$levels.x.original)[,2:1]
+    names(tmp)[1] <- paste0(vnames$x, " (original)")
+    tmp$Cell <- vlevels$cell
+    print(tmp, print.gap=3)
+    
+  }
+  
+  
   cat("\n\n --------------------- Regression Model --------------------- \n")
   
   tmp <- paste0("E(Y|X",label.covs,") = ")
@@ -87,7 +107,9 @@ setMethod("show", "effectlite", function(object) {
   ## print coefficients of g-Functions  
   for(i in 1:ng){
     if(i==1){
-      tmp <- paste0("Intercept Function g",i-1,label.g.function)
+      tmp <- paste0("Intercept Function g",i-1,label.g.function,
+                    "  [Reference group: ", 
+                    paste0(object@input@control), "]")
       cat("\n",tmp, "\n\n")
     }else{
       tmp <- paste0("Effect Function g",i-1,label.g.function)
@@ -104,22 +126,6 @@ setMethod("show", "effectlite", function(object) {
   
   cat("\n\n--------------------- Cell Counts  --------------------- \n\n")
 
-  
-  if(nk>1){
-    cat("\nCells \n")
-    tmp <- expand.grid(K=vlevels$kstar, X=vlevels$levels.x.original)[,2:1]
-    tmp$Cell <- vlevels$cell
-    print(tmp, print.gap=3)
-    
-  }
-  
-  if(nk==1){
-    cat("Cells \n")
-    tmp <- data.frame(X=vlevels$levels.x.original)
-    print(tmp, row.names=F, print.gap=3)
-    
-  }
-  
   cat("\n")
   cat("Cell Counts \n\n")
   cat("This table shows cell counts including missings. \n")
